# prometheus-virtual-metrics

[![PyPI - Version](https://img.shields.io/pypi/v/prometheus-virtual-metrics)](https://pypi.org/project/prometheus-virtual-metrics)
[![PyPI - License](https://img.shields.io/pypi/l/prometheus-virtual-metrics)](https://github.com/fscherf/prometheus-virtual-metrics/blob/master/LICENSE.txt)

prometheus-virtual-metrics is a [Prometheus HTTP API](https://prometheus.io/docs/prometheus/latest/querying/api/)
compatible server [Python](https://python.org) server designed to statelessly
connect [Grafana](https://grafana.com/) to almost anything by implementing
simple plugins.

**Documentation:** [pages.fscherf.de/prometheus-virtual-metrics](https://pages.fscherf.de/prometheus-virtual-metrics/)
